/// A symbol used to identify a function or variable.
#[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
pub struct Symbol(pub String);

impl Symbol {
    /// Create a new `Symbol` from a string.
    pub fn from<S>(s: S) -> Self
    where
        S: Into<String>,
    {
        Self(s.into())
    }
}

impl std::fmt::Display for Symbol {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        write!(f, "{}", self.0)
    }
}

#[cfg(test)]
mod tests {
    use super::*;

    #[test]
    fn display() {
        assert_eq!(Symbol::from("foo").to_string(), "foo");
        assert_eq!(Symbol::from("+").to_string(), "+");
        assert_eq!(Symbol::from("bar0").to_string(), "bar0");
    }
}
